Tutorials
=========

We will demonstrate an example usage of ovrlpy on 2 different datasets:

- `Xenium Brain <https://www.10xgenomics.com/products/xenium-in-situ/mouse-brain-dataset-explorer>`_
- `Vizgen liver <https://info.vizgen.com/mouse-liver-data>`_

You can find the tutorial notebooks
`here <https://github.com/HiDiHlabs/ovrl.py/tree/main/docs/source/tutorials>`_.

.. note::

   To follow along the tutorials make sure you have installed all required dependencies.
   For more information refer to the :ref:`installation instructions <install-tutorial>`.


.. toctree::
   :maxdepth: 1
   :caption: Contents:

   xenium_brain
   vizgen_liver
